import { URI, Emitter, Event, DisposableCollection, IDisposable, BinaryBuffer, ParsedPattern, Uri } from '@opensumi/ide-core-browser';
import { CorePreferences } from '@opensumi/ide-core-browser/lib/core-preferences';
import { FileSystemProviderCapabilities } from '@opensumi/ide-core-common';
import { FileStat, FileDeleteOptions, FileMoveOptions, IBrowserFileSystemRegistry, IFileSystemProvider, FileSystemProvider, IFileSystemProviderRegistrationEvent, IFileSystemProviderCapabilitiesChangeEvent } from '../common';
import { FileChangeEvent, DidFilesChangedParams, IFileServiceClient, FileSetContentOptions, FileCreateOptions, FileCopyOptions, IFileServiceWatcher, TextDocumentContentChangeEvent } from '../common';
export declare class BrowserFileSystemRegistryImpl implements IBrowserFileSystemRegistry {
    readonly providers: Map<string, IFileSystemProvider>;
    registerFileSystemProvider(provider: IFileSystemProvider): {
        dispose: () => void;
    };
}
export declare class FileServiceClient implements IFileServiceClient {
    protected readonly watcherWithSchemaMap: Map<string, number[]>;
    protected readonly watcherDisposerMap: Map<number, IDisposable>;
    protected readonly onFileChangedEmitter: Emitter<FileChangeEvent>;
    protected readonly onFileProviderChangedEmitter: Emitter<string[]>;
    protected readonly _onFilesChanged: Emitter<FileChangeEvent>;
    readonly onFilesChanged: Event<FileChangeEvent>;
    protected readonly _onFileProviderChanged: Emitter<string[]>;
    readonly onFileProviderChanged: Event<string[]>;
    protected readonly _onDidChangeFileSystemProviderRegistrations: Emitter<IFileSystemProviderRegistrationEvent>;
    readonly onDidChangeFileSystemProviderRegistrations: Event<IFileSystemProviderRegistrationEvent>;
    private readonly _onDidChangeFileSystemProviderCapabilities;
    readonly onDidChangeFileSystemProviderCapabilities: Event<IFileSystemProviderCapabilitiesChangeEvent>;
    protected filesExcludesMatcherList: ParsedPattern[];
    protected watcherId: number;
    protected toDisposable: DisposableCollection;
    protected watchFileExcludes: string[];
    protected watchFileExcludesMatcherList: ParsedPattern[];
    protected filesExcludes: string[];
    protected workspaceRoots: string[];
    private _providerChanged;
    private registry;
    private fsProviders;
    private injector;
    private eventBus;
    private readonly appConfig;
    private userHomeDeferred;
    options: {
        encoding: string;
        overwrite: boolean;
        recursive: boolean;
        moveToTrash: boolean;
    };
    constructor();
    private doGetCurrentUserHome;
    corePreferences: CorePreferences;
    handlesScheme(scheme: string): boolean;
    dispose(): void;
    /**
     * 直接先读文件，错误在后端抛出
     * @deprecated 方法在未来或许有变化
     * @param uri URI 地址
     */
    resolveContent(uri: string, options?: FileSetContentOptions): Promise<{
        content: string;
    }>;
    readFile(uri: string): Promise<{
        content: BinaryBuffer;
    }>;
    getFileStat(uri: string, withChildren?: boolean): Promise<FileStat | undefined>;
    setContent(file: FileStat, content: string | Uint8Array, options?: FileSetContentOptions): Promise<void | FileStat>;
    updateContent(file: FileStat, contentChanges: TextDocumentContentChangeEvent[], options?: FileSetContentOptions): Promise<FileStat>;
    createFile(uri: string, options?: FileCreateOptions): Promise<any>;
    createFolder(uri: string): Promise<FileStat>;
    move(sourceUri: string, targetUri: string, options?: FileMoveOptions): Promise<FileStat>;
    copy(sourceUri: string, targetUri: string, options?: FileCopyOptions): Promise<FileStat>;
    getFsPath(uri: string): Promise<string | undefined>;
    fireFilesChange(event: DidFilesChangedParams): void;
    private uriWatcherMap;
    watchFileChanges(uri: URI, excludes?: string[]): Promise<IFileServiceWatcher>;
    setWatchFileExcludes(excludes: string[]): Promise<void>;
    getWatchFileExcludes(): Promise<string[]>;
    setFilesExcludes(excludes: string[], roots?: string[]): Promise<void>;
    setWorkspaceRoots(roots: string[]): Promise<void>;
    unwatchFileChanges(watcherId: number): Promise<void>;
    delete(uriString: string, options?: FileDeleteOptions): Promise<void>;
    getEncoding(uri: string): Promise<string>;
    listCapabilities(): Iterable<{
        scheme: string;
        capabilities: FileSystemProviderCapabilities;
    }>;
    registerProvider(scheme: string, provider: FileSystemProvider): IDisposable;
    access(uri: string, mode?: number): Promise<boolean>;
    getFileType(uri: string): Promise<string | undefined>;
    getCurrentUserHome(): Promise<FileStat | undefined>;
    private getErrorProvideNotSupport;
    /**
     * 提供一个方法让集成方对该方法进行复写。
     * 如双容器架构中对 IDE 容器读取不到的研发容器目录进行 scheme 替换，让插件提供提供的 fs-provider 去读取
     */
    protected convertUri(uri: string | Uri): URI;
    private updateExcludeMatcher;
    private getProvider;
    isReadonly(uriString: string): Promise<boolean>;
    private isExclude;
    private filterStat;
    private filterStatChildren;
    protected applyContentChanges(content: string, contentChanges: TextDocumentContentChangeEvent[]): string;
    protected isInSync(file: FileStat, stat: FileStat): Promise<boolean>;
    protected checkInSync(file: FileStat, stat: FileStat): boolean;
    protected createOutOfSyncError(file: FileStat): Error;
    protected doGetEncoding(option?: {
        encoding?: string;
    }): Promise<string>;
    protected doGetOverwrite(option?: {
        overwrite?: boolean;
    }): Promise<boolean | undefined>;
    protected doGetRecursive(option?: {
        recursive?: boolean;
    }): Promise<boolean>;
    protected doGetMoveToTrash(option?: {
        moveToTrash?: boolean;
    }): Promise<boolean>;
}
//# sourceMappingURL=file-service-client.d.ts.map