"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DiskFsProviderClient = exports.CoreFileServiceProviderClient = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const ide_core_common_1 = require("@opensumi/ide-core-common");
const common_1 = require("../common");
class CoreFileServiceProviderClient {
    constructor() {
        this.onDidChangeFileEmitter = new ide_core_common_1.Emitter();
        this.onDidChangeFile = this.onDidChangeFileEmitter.event;
    }
    watch(uri, options) {
        return this.fileServiceProvider.watch(uri, options);
    }
    unwatch(watcherId) {
        return this.fileServiceProvider.unwatch && this.fileServiceProvider.unwatch(watcherId);
    }
    async stat(uri) {
        const stat = await this.fileServiceProvider.stat(uri);
        return stat;
    }
    readDirectory(uri) {
        return this.fileServiceProvider.readDirectory(uri);
    }
    createDirectory(uri) {
        return this.fileServiceProvider.createDirectory(uri);
    }
    async readFile(uri, encoding) {
        if (encoding) {
            (0, ide_core_common_1.getDebugLogger)('fileService.fsProvider').warn('encoding option for fsProvider.readFile is deprecated');
        }
        const buffer = await this.fileServiceProvider.readFile(uri);
        return buffer;
    }
    writeFile(uri, content, options) {
        // TODO: 转换放到connection抹平
        return this.fileServiceProvider.writeFile(uri, Array.from(content), options);
    }
    delete(uri, options) {
        return this.fileServiceProvider.delete(uri, options);
    }
    rename(oldUri, newUri, options) {
        return this.fileServiceProvider.rename(oldUri, newUri, options);
    }
}
tslib_1.__decorate([
    (0, di_1.Autowired)(di_1.INJECTOR_TOKEN),
    tslib_1.__metadata("design:type", di_1.Injector)
], CoreFileServiceProviderClient.prototype, "injector", void 0);
exports.CoreFileServiceProviderClient = CoreFileServiceProviderClient;
let DiskFsProviderClient = class DiskFsProviderClient extends CoreFileServiceProviderClient {
    constructor() {
        super(...arguments);
        this.onDidChangeCapabilities = ide_core_common_1.Event.None;
    }
    get capabilities() {
        if (!this._capabilities) {
            this._capabilities =
                2 /* FileSystemProviderCapabilities.FileReadWrite */ |
                    4 /* FileSystemProviderCapabilities.FileOpenReadWriteClose */ |
                    16 /* FileSystemProviderCapabilities.FileReadStream */ |
                    8 /* FileSystemProviderCapabilities.FileFolderCopy */ |
                    8192 /* FileSystemProviderCapabilities.FileWriteUnlock */ |
                    4096 /* FileSystemProviderCapabilities.Trash */;
            if (ide_core_common_1.isLinux) {
                this._capabilities |= 1024 /* FileSystemProviderCapabilities.PathCaseSensitive */;
            }
        }
        return this._capabilities;
    }
    setWatchFileExcludes(excludes) {
        return this.fileServiceProvider.setWatchFileExcludes(excludes);
    }
    getWatchFileExcludes() {
        return this.fileServiceProvider.getWatchFileExcludes();
    }
    onDidFilesChanged(event) {
        const changes = event.changes.map((change) => ({
            uri: change.uri,
            type: change.type,
        }));
        this.onDidChangeFileEmitter.fire(changes);
    }
    copy(source, destination, options) {
        return this.fileServiceProvider.copy(source, destination, options);
    }
    access(uri, mode) {
        return this.fileServiceProvider.access(uri, mode);
    }
    getCurrentUserHome() {
        return this.fileServiceProvider.getCurrentUserHome();
    }
    getFileType(uri) {
        return this.fileServiceProvider.getFileType(uri);
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(common_1.DiskFileServicePath),
    tslib_1.__metadata("design:type", Object)
], DiskFsProviderClient.prototype, "fileServiceProvider", void 0);
tslib_1.__decorate([
    (0, ide_core_common_1.debounce)(100),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Array]),
    tslib_1.__metadata("design:returntype", void 0)
], DiskFsProviderClient.prototype, "setWatchFileExcludes", null);
DiskFsProviderClient = tslib_1.__decorate([
    (0, di_1.Injectable)()
], DiskFsProviderClient);
exports.DiskFsProviderClient = DiskFsProviderClient;
//# sourceMappingURL=file-service-provider-client.js.map