import ParcelWatcher from '@parcel/watcher';
import { ParsedPattern, DisposableCollection } from '@opensumi/ide-core-node';
import { FileChangeType, FileSystemWatcherClient, IFileSystemWatcherServer, WatchOptions } from '../common';
import { FileChangeCollection } from './file-change-collection';
export interface WatcherOptions {
    excludesPattern: ParsedPattern[];
    excludes: string[];
}
/**
 * @deprecated
 */
export interface NsfwFileSystemWatcherOption {
    verbose?: boolean;
    info?: (message: string, ...args: any[]) => void;
    error?: (message: string, ...args: any[]) => void;
}
export declare class FileSystemWatcherServer implements IFileSystemWatcherServer {
    private readonly excludes;
    private static readonly PARCEL_WATCHER_BACKEND;
    private WATCHER_HANDLERS;
    private static WATCHER_SEQUENCE;
    protected watcherOptions: Map<number, WatcherOptions>;
    protected client: FileSystemWatcherClient | undefined;
    protected readonly toDispose: DisposableCollection;
    protected changes: FileChangeCollection;
    private readonly loggerManager;
    private logger;
    constructor(excludes?: string[]);
    dispose(): void;
    /**
     * 查找某个路径是否已被监听
     * @param watcherPath
     */
    checkIsAlreadyWatched(watcherPath: string): number | undefined;
    /**
     * 如果监听路径不存在，则会监听父目录
     * @param uri 要监听的路径
     * @param options
     * @returns
     */
    watchFileChanges(uri: string, options?: WatchOptions): Promise<number>;
    /**
     * 向上查找存在的目录
     * 默认向上查找 5 层，避免造成较大的目录监听带来的性能问题
     * 当前框架内所有配置文件可能存在的路径层级均不超过 5 层
     * @param path 监听的文件路径
     * @param count 向上查找层级
     */
    protected lookup(path: string, count?: number): Promise<string>;
    /**
     * 过滤 `write-file-atomic` 写入生成的临时文件
     * @param events
     */
    protected trimChangeEvent(events: ParcelWatcher.Event[]): ParcelWatcher.Event[];
    private isTempFile;
    private getDefaultWatchExclude;
    protected start(watcherId: number, basePath: string, rawOptions: WatchOptions | undefined): Promise<DisposableCollection>;
    unwatchFileChanges(watcherId: number): Promise<void>;
    setClient(client: FileSystemWatcherClient | undefined): void;
    /**
     * @deprecated
     * 主要是用来跳过 jest 测试
     */
    private isEnableNSFW;
    private handleNSFWEvents;
    private withNSFWModule;
    protected pushAdded(path: string): void;
    protected pushUpdated(path: string): void;
    protected pushDeleted(path: string): void;
    protected pushFileChange(path: string, type: FileChangeType): void;
    protected resolvePath(directory: string, file: string): string;
    /**
     * Fires file changes to clients.
     * It is debounced in the case if the filesystem is spamming to avoid overwhelming clients with events.
     */
    protected readonly fireDidFilesChanged: () => void;
    protected doFireDidFilesChanged(): void;
}
//# sourceMappingURL=file-service-watcher.d.ts.map